@@ -9,22 +9,29 @@
 #' The resulting full NEXUS script is output as a set of character strings either
 #' printed to the R console, or output to file which is then overwritten.
 #' 
+
+
+#' @details
 #' Users must supply a data set of tip ages (in various formats),
 #' which are used to construct age calibrations commands on the tip taxa 
 #' (via paleotree function \code{\link{createMrBayesTipCalibrations}}). 
 #' The user must also supply some topological constraint: 
-#' either a set of taxa designated as the outgroup, which is then converted into a command constraining
-#' the monophyly on the ingroup taxa, which is presumed to be all taxa \emph{not} listed in the outgroup. 
-#' Alternatively, a user may supply a tree which is then converted into a series of hard topological
-#' constraints (via function \code{\link{createMrBayesConstraints}}. Both types of topological constraints
-#' cannot be applied. Many of the options available with \code{\link{createMrBayesTipCalibrations}} are available with this function,
-#' allowing users to choose between fixed calibrations or uniform priors that approximate stratigraphic uncertainty.
+#' either a set of taxa designated as the outgroup, which
+#' is then converted into a command constraining
+#' the monophyly on the ingroup taxa, which is presumed to be
+#' all taxa \emph{not} listed in the outgroup. 
+#' Alternatively, a user may supply a tree which is then
+#' converted into a series of hard topological constraints 
+#' (via function \code{\link{createMrBayesConstraints}}.
+#' Both types of topological constraints cannot be applied. 
+#' 
+#' Many of the options available with \code{\link{createMrBayesTipCalibrations}}
+#' are available with this function, allowing users to choose between fixed
+#' calibrations or uniform priors that approximate stratigraphic uncertainty.
 #' In addition, the user may also supply a path to a text file
-#' presumed to be a NEXUS file containing character data formatted for use with \emph{MrBayes}.
+#' presumed to be a NEXUS file containing character
+#' data formatted for use with \emph{MrBayes}.
 #' 
-
-
-#' @details
 #' The taxa listed in \code{tipTimes} must match the taxa in 
 #' \code{treeConstraints}, if such is supplied. If supplied, the taxa in \code{outgroupTaxa}
 #' must be contained within this same set of taxa. These all must have matches
@@ -43,7 +50,8 @@
 #'  All taxa not listed in the outgroup will be constrained to be a monophyletic ingroup, for sake of rooting
 #' the resulting dated tree.
 #' Either \code{treeConstraints} or \code{outgroupTaxa} must be defined, but \emph{not both}. 
-#' If the outgroup-ingroup split is not present on the supplied \code{treeConstraints}, add that split to \code{treeConstraints} manually.
+#' If the outgroup-ingroup split is not present on the supplied
+#' \code{treeConstraints}, add that split to \code{treeConstraints} manually.
 
 
 #' @param whichAppearance Which appearance date of the taxa should be used:
@@ -65,9 +73,9 @@
 #' first occurrence in temporal order (but the assignment, in that case, was entirely
 #' arbitrary). When \code{whichAppearance = "rangeThrough"}, each taxon will be
 #' duplicated into as many OTUs as each
-#' interval that a taxon ranges through (in a timeList format, see other
-#' paleotree functions), with the corresponding age uncertainties for those intervals.
-#' If the input tipTimes is not a list of length = 2, however, the function will 
+#' interval that a taxon ranges through (in a \code{timeList} format, see other
+#' \code{paleotree} functions), with the corresponding age uncertainties for those intervals.
+#' If the input \code{tipTimes} is not a list of \code{length = 2}, however, the function will 
 #' return an error under this option. 
 
 #' @param orderedChars Should be a vector of numbers, indicating which characters should have their
@@ -110,7 +118,7 @@
 #' determined entirely by the fossilized birth-death prior, with no impact from a
 #' presupposed morphological clock (thus a 'clock-less analysis').
 
-#' @param runName The name of the run, used for naming the log files. 
+#' @param runName The name of the run, used for naming the log files and MCMC output files. 
 #' If not set, the name will be taken from the name given for outputting
 #' the NEXUS script (\code{newFile}). If \code{newFile} is not given, and
 #' \code{runName} is not set by the user, the default run name will be  "new_run_paleotree".
@@ -119,6 +127,11 @@
 #' \emph{MrBayes} will be left out. Useful for troubleshooting initial runs of scripts for non-fatal errors and
 #' warnings (such as ignored constraints). Default for this argument is \code{FALSE}.
 
+#' @param autoCloseMrB If \code{TRUE}, the MrBayes script created by this function will
+#' 'autoclose', so that when an MCMC run finishes the specified number of generations,
+#' it does not interactively check whether to continue the MCMC. This is often necessary
+#' for batch analyses.
+
 #' @param treeConstraints An object of class \code{phylo}, 
 #' from which (if \code{treeConstraints} is supplied) the set topological constraints are derived, as
 #' as described for argument \code{tree} for function \code{createMrBayesConstraints}. 
@@ -127,12 +140,25 @@
 
 #' @param morphModel This argument can be used to switch between two end-member models of 
 #' morphological evolution in MrBayes, here named 'strong' and 'relaxed', for the 'strong assumptions'
-#' and 'relaxed assumptions' models described by Bapst, Schreiber and Carlson (Systematic Biology).
+#' and 'relaxed assumptions' models described by Bapst et al. (2018, Syst. Biol.).
 #' The default is a model which makes very 'strong' assumptions about the process of morphological evolution,
 #' while the 'relaxed' alternative allows for considerably more heterogeneity in the rate
 #' of morphological evolution across characters, and in the forward and reverse transition
-#' rates between states. Note that in both cases, the character data is assumed to be filtered
-#' to only parsimony-informative characters, without autapomorphies.
+#' rates between states. Also see argument \code{morphFiltered}.
+
+#' @param morphFiltered This argument controls what type of filtering the input
+#' morphological data is assumed to have been collected under. The likelihood of
+#' the character data will be modified to take into account the apparent filtering
+#' (Lewis, 2001; Allman et al., 2010). The default value, \code{"parsInf"}, forces
+#' characters to be treated as if they were collected as part of a parsimony-based
+#' study, with constant characters and autapomorphies (characters that only differ
+#' in state in a single taxon unit) ignored or otherwise filtered out, and any such
+#' characters in the presented matrix will be ignored. \code{morphFiltered = "variable"}
+#' assumes that while constant characters are still filtered out (e.g. it is
+#' difficult or impossible to count the number of morphological characters that
+#' show no variation across a group), the autapomorphies were intentionally collected
+#' and included in the presented matrix. Thus, constant characters in the included
+#' matrix will be ignored, but autapomorphies will be considered. 
 
 #' @param cleanNames If \code{TRUE} (the default), then special characters
 #' (currently, this only contains the forward-slashes: '/') are removed from
@@ -198,18 +224,18 @@
 #' 
 #' Matzke, N. J., and A. Wright. 2016. Inferring node dates from tip dates
 #' in fossil Canidae: the importance of tree priors. \emph{Biology Letters} 12(8).
-#'
+#' 
 #' The rationale behind the two alternative morphological models are described in more detail here:
 #' 
-#' Bapst, D. W., H. A. Schreiber, and S. J. Carlson. In press. Combined analysis of extant Rhynchonellida
-#' (Brachiopoda) using morphological and molecular data. \emph{Systematic Biology} doi: 10.1093/sysbio/syx049
-#' 
+#' Bapst, D. W., H. A. Schreiber, and S. J. Carlson. 2018.
+#' Combined Analysis of Extant Rhynchonellida (Brachiopoda) using Morphological
+#' and Molecular Data. \emph{Systematic Biology} 67(1):32-48. doi: 10.1093/sysbio/syx049
+#
+
 
 
 
 #' @examples
-#'
-#' # let's do some examples
 #' 
 #' # load retiolitid dataset
 #' data(retiolitinae)
@@ -293,10 +319,13 @@ createMrBayesTipDatingNexus <- function(tipTimes,outgroupTaxa = NULL,treeConstra
 							collapseUniform = TRUE,anchorTaxon = TRUE,
 							newFile = NULL,origNexusFile = NULL, 
 							parseOriginalNexus = TRUE,createEmptyMorphMat = TRUE,
-							orderedChars=NULL, morphModel = "strong",
-							runName = NULL, ngen = "100000000", doNotRun = FALSE,
+							orderedChars=NULL, 
+							morphModel = "strong", morphFiltered = "parsInf",
+							runName = NULL, ngen = "100000000",
+							doNotRun = FALSE, autoCloseMrB = FALSE,
 							cleanNames = TRUE, printExecute = TRUE){
 	################################################################################################
+	#
 	#         # a wooper of a function ... here's some ASCII from artist 'Psyduck'
 	#
 	#                        = @@@@@@                         
@@ -472,7 +501,10 @@ createMrBayesTipDatingNexus <- function(tipTimes,outgroupTaxa = NULL,treeConstra
 		stop("morphModel must be one 'relaxed' or 'strong'")
 		}
 	if(morphModel == "relaxed" & is.null(origNexusFile)){
-		warning("Why are you relaxing the morphological model without supplying an original matrix with origNexusFile? I hope you know what you are doing.")
+		warning(paste0(
+			"Why are you relaxing the morphological model without supplying an original matrix with origNexusFile?",
+			"\n   I hope you know what you are doing...\n"
+			))
 		}
 	#
 	if(!is.character(ngen)){
@@ -543,7 +575,8 @@ createMrBayesTipDatingNexus <- function(tipTimes,outgroupTaxa = NULL,treeConstra
 				stop("tipTimes must be a timeList object if 'whichAppearance  = rangeThrough'")
 				}
 			# for each taxon in tipTimes, figure out intervals they range through
-				# and then multiply this taxon in the tip data, the tree/root constraints and NEXUS data block
+				# and then multiply this taxon in the tip data,
+				# the tree/root constraints and NEXUS data block
 			#
 			newOTU <- matrix(,1,4)
 			for(i in 1:nrow(tipTimes[[2]])){
@@ -564,7 +597,10 @@ createMrBayesTipDatingNexus <- function(tipTimes,outgroupTaxa = NULL,treeConstra
 			newOTU <- matrix(,1,4)
 			if(!is.list(tipTimes)){
 				if(ncol(tipTimes)!=4){
-					stop("tipTimes if not a timeList object must have four columns, indicating uncertainty bounds on FADs and LADS separately")
+					stop(paste0(
+						"tipTimes if not a timeList object must have four columns,\n",
+						"  indicating uncertainty bounds on FADs and LADS separately"
+						))
 					}
 				for(i in 1:nrow(tipTimes)){
 					# count number of range-through intervals, get dates and new names
@@ -634,7 +670,10 @@ createMrBayesTipDatingNexus <- function(tipTimes,outgroupTaxa = NULL,treeConstra
 	########################################
 	# check that morphNexus has been replaced
 	if(is.null(morphNexus)){
-		stop("a morphological nexus was neither provided nor created - please contact dwbapst@gmail.com about this bug")
+		stop(paste0(
+		"A morphological nexus was neither provided nor created.\n",
+		"   Please contact dwbapst@gmail.com about this bug."
+		))
 		}
 	#}else{
 	#	morphNexus <- nexusFileText
@@ -652,6 +691,8 @@ createMrBayesTipDatingNexus <- function(tipTimes,outgroupTaxa = NULL,treeConstra
 		}
 	# use run name as log file name
 	logfileline <- paste0('log start filename = "',runName,'.out" replace;')
+	# use run name for MCMC output files
+	outputNameLine <- paste0('Filename = "',runName,'"')
 	########################################################
 	#	
 	if(is.null(treeConstraints)){
@@ -677,10 +718,13 @@ createMrBayesTipDatingNexus <- function(tipTimes,outgroupTaxa = NULL,treeConstra
 		ingroupBlock = ingroupConstraint,
 		ageBlock = ageCalibrations, 
 		constraintBlock = topologicalConstraints,
-		orderedChars=orderedChars,		
+		orderedChars=orderedChars,
+		autoCloseMrB = autoCloseMrB,
 		morphModel = morphModel, 
+		morphFiltered = morphFiltered,
 		ngen = ngen, 
-		doNotRun = doNotRun)
+		doNotRun = doNotRun,
+		outputNameLine = outputNameLine)
 	###############################################
 	# combine morph matrix block with MrBayes command block
 	finalText <- c(morphNexus,MrBayesBlock)
@@ -689,7 +733,7 @@ createMrBayesTipDatingNexus <- function(tipTimes,outgroupTaxa = NULL,treeConstra
 		if(printExecute){
 			# have function print command for pasting into MrBayes to execute: 
 				# e.g. ' Execute "C://fossil data/myNexus.nex" '
-			message("Now go to MrBayes and paste in this line:")
+			message("Now go to MrBayes and paste in this line:  ")
 			message(paste0('Execute "',normalizePath(newFile),'";'))
 			}
 	}else{
@@ -782,8 +826,12 @@ makeEmptyMorphNexusMrB <- function(taxonNames){
 
 
 
-makeMrBayesBlock <- function(logBlock,ingroupBlock,ageBlock,orderedChars,
-							constraintBlock,morphModel = "strong",ngen = 100000000,doNotRun = FALSE){
+makeMrBayesBlock <- function(logBlock, ingroupBlock,
+							ageBlock, orderedChars, autoCloseMrB,
+							constraintBlock, morphModel = "strong",
+							morphFiltered="parsInf",
+							ngen = 100000000, doNotRun = FALSE,
+							outputNameLine = outputNameLine){
 #########################################################################################						
 	###
 	### # what follows will look very messy due to its untabbed nature
@@ -793,13 +841,18 @@ makeMrBayesBlock <- function(logBlock,ingroupBlock,ageBlock,orderedChars,
 block1 <- "
 begin mrbayes;
 
-[This block is a combination of best practices taken from NEXUS files from April Wright,
-     William Gearty, Graham Slater, Davey Wright, and guided by the 
-	 recommendations of Matzke and Wright, 2016, Biol. Lett.]
+[This block is a combination of best practices taken from NEXUS files from
+     April Wright, William Gearty, Graham Slater, Davey Wright,
+	 and guided by the recommendations of Matzke and Wright, 2016, Biol. Lett.]
+
+[autoclose, I like it to ask (the default), but you might want it - if so, set to 'yes']"
+
+if(autoCloseMrB){
+	block1 <- c(block1,"set autoclose = yes;\n")
+}else{
+	block1 <- c(block1,"[set autoclose = yes;]\n")
+	}
 
-[no autoclose, I like it to ask, but you might want it]
-	[set autoclose = yes;]
-"
 ##########################################################################
 block2 <- "
 [DATA]
@@ -835,7 +888,17 @@ if(!is.null(orderedChars)){
 	}
 
 ##############################################################################
-morphModelBlock_Strong <- "
+if(morphFiltered == "parsInf"){
+	filteredType <- "informative"
+	}
+if(morphFiltered == "variable"){
+	filteredType <- "variable"
+	}
+if(is.null(filteredType)){
+	stop("morphFiltered must be one of 'parsInf' or 'variable'")
+	}
+
+morphModelBlock_Strong <- paste0("
 
 [CHARACTER MODELS]
 	
@@ -844,16 +907,18 @@ morphModelBlock_Strong <- "
 	[default: use pars-informative coding]
 	
 	[set coding and rates - default below maximizes information content]
-		lset  nbetacat = 5 rates = equal Coding = informative; [equal rate variation]
+		lset  nbetacat = 5 rates = equal Coding = ",
+filteredType,
+		"; [equal rate variation]
 		[lset  nbetacat = 5 rates = gamma Coding = informative;   [gamma distributed rate variation]]
 			[gamma distributed rates may cause divide by zero problems with non-fixed symdiri]
 	[symdirhyperpr prior, fixed vs. variable]	
 		prset symdirihyperpr = fixed(infinity);		
 		[prset symdirihyperpr = uniform(1,10);      [this range seems to avoid divide by zero error]]
 
-"
+")
 
-morphModelBlock_Relaxed <- "
+morphModelBlock_Relaxed <- paste0("
 
 [CHARACTER MODELS]
 	
@@ -862,14 +927,16 @@ morphModelBlock_Relaxed <- "
 	[default: use pars-informative coding]
 	
 	[set coding and rates - default below maximizes information content]
-		[lset  nbetacat = 5 rates = equal Coding = informative; [equal rate variation]]
+		[lset  nbetacat = 5 rates = equal Coding = ",
+filteredType,
+		"; [equal rate variation]]
 		lset  nbetacat = 5 rates = gamma Coding = informative;   [gamma distributed rate variation]
 			[gamma distributed rates may cause divide by zero problems with non-fixed symdiri]
 	[symdirhyperpr prior, fixed vs. variable]	
 		[prset symdirihyperpr = fixed(infinity);]		
 		prset symdirihyperpr = uniform(1,10);      [this range seems to avoid divide by zero error]
 
-"
+")
 	
 #############################################################################
 block4 <- "
@@ -950,7 +1017,7 @@ runBlock <- "
 		morphModelBlock <- morphModelBlock_Relaxed
 		}
 	# insert ngen
-	block5 <- paste0(block5a,ngen,block5b)
+	block5 <- paste0(block5a,ngen," ",outputNameLine,block5b)
 	####################
 	finalBlock <- c(
 		block1,
